IntoOwned

Trait IntoOwned 

pub trait IntoOwned {
    type Owned;

    // Required method
    fn into_owned(self) -> Self::Owned;
}
Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.

Required Associated Types

type Owned

The type after obtaining ownership, should be the same as before but with static lifetime.

Required Methods

fn into_owned(self) -> Self::Owned

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.

Implementations on Foreign Types

Source

impl IntoOwned for bool

Source

type Owned = bool

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for char

Source

type Owned = char

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for f32

Source

type Owned = f32

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for f64

Source

type Owned = f64

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for i8

Source

type Owned = i8

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for i16

Source

type Owned = i16

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for i32

Source

type Owned = i32

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for i64

Source

type Owned = i64

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for i128

Source

type Owned = i128

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for isize

Source

impl IntoOwned for u8

Source

type Owned = u8

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for u16

Source

type Owned = u16

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for u32

Source

type Owned = u32

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for u64

Source

type Owned = u64

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for u128

Source

type Owned = u128

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for ()

Source

type Owned = ()

Source

fn into_owned(self) -> Self::Owned

Source

impl IntoOwned for usize

Source

impl IntoOwned for NonZeroI8

Source

impl IntoOwned for NonZeroI16

Source

impl IntoOwned for NonZeroI32

Source

impl IntoOwned for NonZeroI64

Source

impl IntoOwned for NonZeroI128

Source

impl IntoOwned for NonZeroIsize

Source

impl IntoOwned for NonZeroU8

Source

impl IntoOwned for NonZeroU16

Source

impl IntoOwned for NonZeroU32

Source

impl IntoOwned for NonZeroU64

Source

impl IntoOwned for NonZeroU128

Source

impl IntoOwned for NonZeroUsize

Source

impl<K, V> IntoOwned for BTreeMap<K, V>
where K: IntoOwned, <K as IntoOwned>::Owned: Ord, V: IntoOwned,

Source

type Owned = BTreeMap<<K as IntoOwned>::Owned, <V as IntoOwned>::Owned>

Source

fn into_owned(self) -> Self::Owned

Source

impl<K, V, S> IntoOwned for HashMap<K, V, S>
where K: IntoOwned, <K as IntoOwned>::Owned: Eq + Hash, V: IntoOwned, S: BuildHasher + Default,

Available on crate feature std only.
Source

type Owned = HashMap<<K as IntoOwned>::Owned, <V as IntoOwned>::Owned, S>

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned> IntoOwned for (T0,)

Source

type Owned = (<T0 as IntoOwned>::Owned,)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned> IntoOwned for (T0, T1)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned> IntoOwned for (T0, T1, T2)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned, T3: IntoOwned> IntoOwned for (T0, T1, T2, T3)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned, <T3 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned, T3: IntoOwned, T4: IntoOwned> IntoOwned for (T0, T1, T2, T3, T4)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned, <T3 as IntoOwned>::Owned, <T4 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned, T3: IntoOwned, T4: IntoOwned, T5: IntoOwned> IntoOwned for (T0, T1, T2, T3, T4, T5)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned, <T3 as IntoOwned>::Owned, <T4 as IntoOwned>::Owned, <T5 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned, T3: IntoOwned, T4: IntoOwned, T5: IntoOwned, T6: IntoOwned> IntoOwned for (T0, T1, T2, T3, T4, T5, T6)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned, <T3 as IntoOwned>::Owned, <T4 as IntoOwned>::Owned, <T5 as IntoOwned>::Owned, <T6 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned, T3: IntoOwned, T4: IntoOwned, T5: IntoOwned, T6: IntoOwned, T7: IntoOwned> IntoOwned for (T0, T1, T2, T3, T4, T5, T6, T7)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned, <T3 as IntoOwned>::Owned, <T4 as IntoOwned>::Owned, <T5 as IntoOwned>::Owned, <T6 as IntoOwned>::Owned, <T7 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned, T3: IntoOwned, T4: IntoOwned, T5: IntoOwned, T6: IntoOwned, T7: IntoOwned, T8: IntoOwned> IntoOwned for (T0, T1, T2, T3, T4, T5, T6, T7, T8)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned, <T3 as IntoOwned>::Owned, <T4 as IntoOwned>::Owned, <T5 as IntoOwned>::Owned, <T6 as IntoOwned>::Owned, <T7 as IntoOwned>::Owned, <T8 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned, T3: IntoOwned, T4: IntoOwned, T5: IntoOwned, T6: IntoOwned, T7: IntoOwned, T8: IntoOwned, T9: IntoOwned> IntoOwned for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned, <T3 as IntoOwned>::Owned, <T4 as IntoOwned>::Owned, <T5 as IntoOwned>::Owned, <T6 as IntoOwned>::Owned, <T7 as IntoOwned>::Owned, <T8 as IntoOwned>::Owned, <T9 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned, T3: IntoOwned, T4: IntoOwned, T5: IntoOwned, T6: IntoOwned, T7: IntoOwned, T8: IntoOwned, T9: IntoOwned, T10: IntoOwned> IntoOwned for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned, <T3 as IntoOwned>::Owned, <T4 as IntoOwned>::Owned, <T5 as IntoOwned>::Owned, <T6 as IntoOwned>::Owned, <T7 as IntoOwned>::Owned, <T8 as IntoOwned>::Owned, <T9 as IntoOwned>::Owned, <T10 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned, T3: IntoOwned, T4: IntoOwned, T5: IntoOwned, T6: IntoOwned, T7: IntoOwned, T8: IntoOwned, T9: IntoOwned, T10: IntoOwned, T11: IntoOwned> IntoOwned for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned, <T3 as IntoOwned>::Owned, <T4 as IntoOwned>::Owned, <T5 as IntoOwned>::Owned, <T6 as IntoOwned>::Owned, <T7 as IntoOwned>::Owned, <T8 as IntoOwned>::Owned, <T9 as IntoOwned>::Owned, <T10 as IntoOwned>::Owned, <T11 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned, T3: IntoOwned, T4: IntoOwned, T5: IntoOwned, T6: IntoOwned, T7: IntoOwned, T8: IntoOwned, T9: IntoOwned, T10: IntoOwned, T11: IntoOwned, T12: IntoOwned> IntoOwned for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned, <T3 as IntoOwned>::Owned, <T4 as IntoOwned>::Owned, <T5 as IntoOwned>::Owned, <T6 as IntoOwned>::Owned, <T7 as IntoOwned>::Owned, <T8 as IntoOwned>::Owned, <T9 as IntoOwned>::Owned, <T10 as IntoOwned>::Owned, <T11 as IntoOwned>::Owned, <T12 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned, T3: IntoOwned, T4: IntoOwned, T5: IntoOwned, T6: IntoOwned, T7: IntoOwned, T8: IntoOwned, T9: IntoOwned, T10: IntoOwned, T11: IntoOwned, T12: IntoOwned, T13: IntoOwned> IntoOwned for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned, <T3 as IntoOwned>::Owned, <T4 as IntoOwned>::Owned, <T5 as IntoOwned>::Owned, <T6 as IntoOwned>::Owned, <T7 as IntoOwned>::Owned, <T8 as IntoOwned>::Owned, <T9 as IntoOwned>::Owned, <T10 as IntoOwned>::Owned, <T11 as IntoOwned>::Owned, <T12 as IntoOwned>::Owned, <T13 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned, T3: IntoOwned, T4: IntoOwned, T5: IntoOwned, T6: IntoOwned, T7: IntoOwned, T8: IntoOwned, T9: IntoOwned, T10: IntoOwned, T11: IntoOwned, T12: IntoOwned, T13: IntoOwned, T14: IntoOwned> IntoOwned for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned, <T3 as IntoOwned>::Owned, <T4 as IntoOwned>::Owned, <T5 as IntoOwned>::Owned, <T6 as IntoOwned>::Owned, <T7 as IntoOwned>::Owned, <T8 as IntoOwned>::Owned, <T9 as IntoOwned>::Owned, <T10 as IntoOwned>::Owned, <T11 as IntoOwned>::Owned, <T12 as IntoOwned>::Owned, <T13 as IntoOwned>::Owned, <T14 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T0: IntoOwned, T1: IntoOwned, T2: IntoOwned, T3: IntoOwned, T4: IntoOwned, T5: IntoOwned, T6: IntoOwned, T7: IntoOwned, T8: IntoOwned, T9: IntoOwned, T10: IntoOwned, T11: IntoOwned, T12: IntoOwned, T13: IntoOwned, T14: IntoOwned, T15: IntoOwned> IntoOwned for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15)

Source

type Owned = (<T0 as IntoOwned>::Owned, <T1 as IntoOwned>::Owned, <T2 as IntoOwned>::Owned, <T3 as IntoOwned>::Owned, <T4 as IntoOwned>::Owned, <T5 as IntoOwned>::Owned, <T6 as IntoOwned>::Owned, <T7 as IntoOwned>::Owned, <T8 as IntoOwned>::Owned, <T9 as IntoOwned>::Owned, <T10 as IntoOwned>::Owned, <T11 as IntoOwned>::Owned, <T12 as IntoOwned>::Owned, <T13 as IntoOwned>::Owned, <T14 as IntoOwned>::Owned, <T15 as IntoOwned>::Owned)

Source

fn into_owned(self) -> Self::Owned

Source

impl<T> IntoOwned for BinaryHeap<T>
where T: IntoOwned, <T as IntoOwned>::Owned: Ord,

Source

impl<T> IntoOwned for BTreeSet<T>
where T: IntoOwned, <T as IntoOwned>::Owned: Ord,

Source

impl<T> IntoOwned for LinkedList<T>
where T: IntoOwned,

Source

impl<T> IntoOwned for VecDeque<T>
where T: IntoOwned,

Source

impl<T> IntoOwned for Vec<T>
where T: IntoOwned,

Source

type Owned = Vec<<T as IntoOwned>::Owned>

Source

fn into_owned(self) -> Self::Owned

Source

impl<T, S> IntoOwned for HashSet<T, S>
where T: IntoOwned, <T as IntoOwned>::Owned: Eq + Hash, S: BuildHasher + Default,

Available on crate feature std only.
Source

type Owned = HashSet<<T as IntoOwned>::Owned, S>

Source

fn into_owned(self) -> Self::Owned

Source

impl<T, const N: usize> IntoOwned for [T; N]
where T: IntoOwned,

Source

type Owned = [<T as IntoOwned>::Owned; N]

Source

fn into_owned(self) -> Self::Owned

Source

impl<T: ToOwned + ?Sized + 'static> IntoOwned for Cow<'_, T>

Source

type Owned = Cow<'static, T>

Source

fn into_owned(self) -> Cow<'static, T>

Source

impl<T: IntoOwned> IntoOwned for Option<T>

Source

type Owned = Option<<T as IntoOwned>::Owned>

Source

fn into_owned(self) -> Self::Owned

Source

impl<T: IntoOwned> IntoOwned for Box<[T]>

Source

type Owned = Box<[<T as IntoOwned>::Owned]>

Source

fn into_owned(self) -> Self::Owned

Source

impl<T: IntoOwned> IntoOwned for Box<T>

Source

type Owned = Box<<T as IntoOwned>::Owned>

Source

fn into_owned(self) -> Self::Owned

Implementors