pub trait IntoOwned {
type Owned;
// Required method
fn into_owned(self) -> Self::Owned;
}Expand description
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.
Required Associated Types
Required Methods
Sourcefn into_owned(self) -> Self::Owned
fn into_owned(self) -> Self::Owned
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.